@@ -1,5 +1,6 @@
 from arc.middleware import Middleware
 from arc.defaults import DefaultMiddleware, DefaultExceptionHandler
+from arc.staticfiles import StaticFile
 from jinja2.loaders import FileSystemLoader
 from starlette.requests import Request
 from starlette.staticfiles import StaticFiles
@@ -120,7 +121,8 @@ class App:
 
     async def __call__(self, scope, recieve, send):
         if "static" in scope["path"]:
-            await self.static_app(scope, recieve, send)
+            # await self.static_app(scope, recieve, send)
+            return StaticFile(scope["path"])
 
         await self.middleware(scope, recieve, send)
 
